
# Enum: InformationBiomacromoleculeCategory

A term describing the type of the enabler of an activity.

URI: [gocam:InformationBiomacromoleculeCategory](https://w3id.org/gocam/InformationBiomacromoleculeCategory)


## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| GeneOrReferenceProtein |  | biolink.GeneOrGeneProduct |  |
| ProteinIsoform |  |  |  |
| MacromolecularComplex |  |  |  |
| Unknown |  |  |  |
